@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+# -*- mode: python; -*-
 ##
 ## Script to build an indexed representation of a GFF file for efficient
 ## retrieval of genes
@@ -15,21 +15,9 @@ import misopy
 import misopy.gff_utils as gff_utils
 import misopy.pickle_utils as pickle_utils
 import misopy.Gene as gene_utils
+import misopy.misc_utils as misc_utils
 
-COMPRESS_PREFIX = "misocomp"
-
-def load_compressed_ids_to_genes(compressed_filename):
-    """
-    Load mapping from compressed IDs to genes.
-    """
-    if not os.path.exists(compressed_filename):
-        print "Error: %s does not exist." %(compressed_filename)
-        sys.exit(1)
-    compressed_ids_to_genes = {}
-    # Load mapping from gene IDs to their hashes
-    compressed_ids_to_genes = shelve.open(compressed_filename)
-    return compressed_ids_to_genes
-
+COMPRESS_PREFIX = misc_utils.COMPRESS_PREFIX
 
 def compress_event_name(event_name,
                         prefix=COMPRESS_PREFIX):
@@ -37,21 +25,6 @@ def compress_event_name(event_name,
     compressed_event_name = "%s_%s" %(prefix, event_hash)
     return compressed_event_name
 
-
-def is_compressed_name(event_name):
-    return event_name.startswith(COMPRESS_PREFIX)
-
-
-def is_compressed_index(index_filename):
-    """
-    Check if the given index filename uses a compressed (hash)
-    ID or not.
-    """
-    basename = os.path.basename(index_filename)
-    if is_compressed_name(basename):
-        return True
-    return False
-
     
 def serialize_genes(gff_genes,
                     gff_filename,
@@ -217,8 +190,9 @@ def main():
         index_gff(gff_filename, output_dir,
                   compress_id=options.compress_id)
     else:
+        print "Indexer of GFF files for use with MISO."
         print "Need to pass --index, for example:\n"
-        print "index_gff.py --index annotation.gff indexed_annotation/"
+        print "index_gff --index annotation.gff indexed_annotation/"
 
 
 if __name__ == '__main__':
