@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+# -*- mode: python; -*-
 ##
 ## Utilities for working with paired-end reads and
 ## fragment distributions
@@ -268,6 +268,10 @@ def compute_insert_len(bams_to_process,
         output_filename = os.path.join(output_dir,
                                        "%s.insert_len" \
                                        %(os.path.basename(bam_filename)))
+        if not os.path.isfile(bam_filename):
+            print "Cannot find BAM file %s" %(bam_filename)
+            print "Quitting..."
+            sys.exit(1)
         print "Fetching reads in constitutive exons"
         mapped_bam_filename = exon_utils.map_bam2gff(bam_filename,
                                                      const_exons_gff_filename,
@@ -490,6 +494,13 @@ def summarize_insert_len_dist(interval_to_paired_dists,
     output_file.close()
 
 
+def greeting():
+    print "Utility for computing insert length distributions from paired-end " \
+          "BAM files."
+    print "Part of MISO (Mixture of Isoforms model)\n"    
+    print "See --help for usage.\n"
+
+
 def main():
     from optparse import OptionParser
     parser = OptionParser()
@@ -513,7 +524,13 @@ def main():
                       help="Output directory.")
     (options, args) = parser.parse_args()
 
-    if options.output_dir == None:
+    if options.compute_insert_len is None:
+        greeting()
+        return
+
+    if options.output_dir is None:
+        greeting()
+        
         print "Error: need --output-dir."
         return
         
